@@ -1,11 +1,9 @@
 /*
  * This file is part of the Nice GLib ICE library.
  *
- * (C) 2006-2008 Collabora Ltd.
- *  Contact: Dafydd Harries
- *  Contact: Olivier Crete
- * (C) 2006, 2007 Nokia Corporation. All rights reserved.
- *  Contact: Kai Vehmanen
+ * (C) 2008-2009 Collabora Ltd.
+ *  Contact: Youness Alaoui
+ * (C) 2008-2009 Nokia Corporation. All rights reserved.
  *
  * The contents of this file are subject to the Mozilla Public License Version
  * 1.1 (the "License"); you may not use this file except in compliance with
@@ -23,10 +21,7 @@
  * Corporation. All Rights Reserved.
  *
  * Contributors:
- *   Dafydd Harries, Collabora Ltd.
- *   Olivier Crete, Collabora Ltd.
- *   Rémi Denis-Courmont, Nokia
- *   Kai Vehmanen
+ *   Youness Alaoui, Collabora Ltd.
  *
  * Alternatively, the contents of this file may be used under the terms of the
  * the GNU Lesser General Public License Version 2.1 (the "LGPL"), in which
@@ -99,13 +94,13 @@ nice_tcp_bsd_socket_new (NiceAgent *agent, GMainContext *ctx, NiceAddress *addr)
   NiceSocket *sock = g_slice_new0 (NiceSocket);
   TcpPriv *priv;
 
-  if (addr != NULL) {
-    nice_address_copy_to_sockaddr(addr, (struct sockaddr *)&name);
-  } else {
-    memset (&name, 0, sizeof (name));
-    name.ss_family = AF_UNSPEC;
+  if (addr == NULL) {
+    /* We can't connect a tcp socket with no destination address */
+    return NULL;
   }
 
+  nice_address_copy_to_sockaddr(addr, (struct sockaddr *)&name);
+
   if ((sockfd == -1) &&
       ((name.ss_family == AF_UNSPEC) ||
           (name.ss_family == AF_INET))) {
