@@ -73,7 +73,7 @@
 #endif
 
 #else
-#define NICE_COMPATIBILITY NICE_COMPATIBILITY_DRAFT19
+#define NICE_COMPATIBILITY NICE_COMPATIBILITY_RFC5245
 #if USE_LOOPBACK
 #define USE_TURN_SERVER_ORG 1
 #else
